@@ -61,7 +61,7 @@ void usage()
 
             << "Optional arguments:" << std::endl << std::endl
             << "\t-h, --help\t\tPrint this help" << std::endl << std::endl
-            << "\t-a, --attachToProcess\tWxit if given process id is not running anymore" << std::endl
+            << "\t-a, --attachToProcess\tExit if given process id is not running anymore" << std::endl
             << "\t-d, --daemon\t\tDetach the HTTP server daemon from the main process" << std::endl
             << "\t-i, --address\t\tListen only on this ip address, all available ones otherwise" << std::endl
             << "\t-M, --monitorLibrary\tMonitor the XML library file and reload it automatically" << std::endl
@@ -77,6 +77,7 @@ void usage()
             << "\t-z, --nodatealiases\tCreate URL aliases for each content by removing the date" << std::endl
             << "\t-c, --customIndex\tAdd path to custom index.html for welcome page" << std::endl
             << "\t-L, --ipConnectionLimit\tMax number of (concurrent) connections per IP (default: infinite, recommended: >= 6)" << std::endl
+            << "\t-k, --skipInvalid\tStartup even when ZIM files are invalid (those will be skipped)" << std::endl
             << std::endl
 
             << "Documentation:" << std::endl
@@ -197,7 +198,7 @@ int main(int argc, char** argv)
 #endif
 
   std::string rootLocation = "/";
-  kiwix::Library library;
+  auto library = kiwix::Library::create();
   unsigned int nb_threads = DEFAULT_THREADS;
   std::vector<std::string> zimPathes;
   std::string libraryPath;
@@ -217,6 +218,7 @@ int main(int argc, char** argv)
   unsigned int PPID = 0;
   int ipConnectionLimit = 0;
   int searchLimit = 0;
+  bool skipInvalid = false;
 
   static struct option long_options[]
       = {{"daemon", no_argument, 0, 'd'},
@@ -237,6 +239,7 @@ int main(int argc, char** argv)
          {"monitorLibrary", no_argument, 0, 'M'},
          {"ipConnectionLimit", required_argument, 0, 'L'},
          {"searchLimit", required_argument, 0, 's'},
+         {"skipInvalid", no_argument, 0, 'k'},
          {0, 0, 0, 0}};
 
   std::set<int> usedOptions;
@@ -307,6 +310,9 @@ int main(int argc, char** argv)
         case 's':
           searchLimit = atoi(optarg);
           break;
+        case 'k':
+          skipInvalid = true;
+          break;
         case '?':
           usage();
           return 2;
@@ -331,7 +337,7 @@ int main(int argc, char** argv)
   }
 
   /* Setup the library manager and get the list of books */
-  kiwix::Manager manager(&library);
+  kiwix::Manager manager(library);
   std::vector<std::string> libraryPaths;
   if (libraryFlag) {
     libraryPaths = kiwix::split(libraryPath, ";");
@@ -340,7 +346,7 @@ int main(int argc, char** argv)
     }
 
     /* Check if the library is not empty (or only remote books)*/
-    if (library.getBookCount(true, false) == 0) {
+    if (library->getBookCount(true, false) == 0) {
       std::cerr << "The XML library file '" << libraryPath
            << "' is empty (or has only remote books)." << std::endl;
     }
@@ -348,9 +354,13 @@ int main(int argc, char** argv)
     std::vector<std::string>::iterator it;
     for (it = zimPathes.begin(); it != zimPathes.end(); it++) {
       if (!manager.addBookFromPath(*it, *it, "", false)) {
-        std::cerr << "Unable to add the ZIM file '" << *it
-             << "' to the internal library." << std::endl;
-        exit(1);
+        if (skipInvalid) {
+          std::cerr << "Skipping invalid '" << *it << "' ...continuing" << std::endl;
+        } else {
+          std::cerr << "Unable to add the ZIM file '" << *it
+               << "' to the internal library." << std::endl;
+          exit(1);
+        }
       }
     }
   }
@@ -376,8 +386,8 @@ int main(int argc, char** argv)
   }
 #endif
 
-  kiwix::UpdatableNameMapper nameMapper(library, noDateAliasesFlag);
-  kiwix::Server server(&library, &nameMapper);
+  auto nameMapper = std::make_shared<kiwix::UpdatableNameMapper>(library, noDateAliasesFlag);
+  kiwix::Server server(library, nameMapper);
 
   if (!customIndexPath.empty()) {
     try {
@@ -447,7 +457,7 @@ int main(int argc, char** argv)
     if ( libraryMustBeReloaded && !libraryPaths.empty() ) {
       libraryFileTimestamp = curLibraryFileTimestamp;
       reloadLibrary(manager, libraryPaths);
-      nameMapper.update();
+      nameMapper->update();
       libraryMustBeReloaded = false;
     }
   } while (waiting);
